package com.onlinebank.transaction.dao;

import com.onlinebank.transaction.to.TransactionCriteria;
import com.onlinebank.transaction.to.TransactionSearchResult;
import com.onlinebank.util.exception.DAOException;

/**
 * This is a DAO interface that declares all transaction data access methods.
 * This interface is the critical part of the DAO pattern which allows to create
 * multiple implementations of the DAO (JDBC implementation, test
 * implementation, etc).
 * 
 * @author Leon Rubin
 */
public interface TransactionDAO {
	/**
	 * Finds all transactions that fit the specified criteria.
	 * 
	 * @param transactionCriteria
	 *            transaction search criteria object
	 * @return TransactionSearchResult containing a list of transactions that
	 *         satisfy the specified criteria
	 * @throws DAOException
	 *             if any data access problems occur
	 */
	TransactionSearchResult findTransactions(
			TransactionCriteria transactionCriteria) throws DAOException;
}
