package com.onlinebank.transaction.dao;

import com.onlinebank.transaction.dao.test.TransactionDAOTestImpl;

/**
 * This is a DAO factory class responsible for creating the instance of the
 * Transaciton DAO. This class is the critical part of the DAO pattern which
 * allows to create multiple implementations of the DAO (JDBC implementation,
 * test implementation, etc).
 * 
 * @author Leon Rubin
 */
public class TransactionDAOFactory {
	private static TransactionDAO dao;

	/**
	 * Creates and returns an instance of the transaction DAO. This method is
	 * the only place in the applciation that knows what class is used to
	 * implement the DAO interface. This method implements a singleton patterns
	 * so the same instance is returned for every call.
	 * 
	 * @return TransactionDAO instance
	 */
	public static TransactionDAO getDAO() {
		if (dao == null) {
			dao = new TransactionDAOTestImpl();
		}

		return dao;
	}
}
