package com.onlinebank.transaction.to;

import java.io.Serializable;
import java.util.Date;

/**
 * This class is a transfer object that represents the transaction search
 * criteria as a single object. It is convenient to have all parameters to the
 * service as a single object because as the number of fields in the criteria
 * grow, the signature of all methods that accept the criteria does not have to
 * change, which is very helpful in an application with many layers.
 * 
 * @author Leon Rubin
 * 
 */
public class TransactionCriteria implements Serializable {
	private static final long serialVersionUID = 1L;
	private String accountNumber;
	private Date fromDate;
	private Date toDate;

	/**
	 * Creates transaction criteria.
	 */
	public TransactionCriteria() {

	}

	/**
	 * Gets the value of the account number parameter
	 * 
	 * @return String containing the value of the account number parameter
	 */
	public String getAccountNumber() {
		return accountNumber;
	}

	/**
	 * Sets the value of the account number parameter
	 * 
	 * @param accountNumber
	 *            value of the account number parameter
	 */
	public void setAccountNumber(String accountNumber) {
		this.accountNumber = accountNumber;
	}

	/**
	 * Gets the value of the from date parameter
	 * 
	 * @return Date containing the value of the from date parameter
	 */
	public Date getFromDate() {
		return fromDate;
	}

	/**
	 * Sets the value of the from date parameter
	 * 
	 * @param fromDate
	 *            value of the from date parameter
	 */
	public void setFromDate(Date fromDate) {
		this.fromDate = fromDate;
	}

	/**
	 * Gets the value of the to date parameter
	 * 
	 * @return Date containing the value of the to date parameter
	 */
	public Date getToDate() {
		return toDate;
	}

	/**
	 * Sets the value of the to date parameter
	 * 
	 * @param fromDate
	 *            value of the to date parameter
	 */
	public void setToDate(Date toDate) {
		this.toDate = toDate;
	}
}
