package com.democompany.soa.esb.adaptor.util.exception;

import java.util.ArrayList;
import java.util.List;

/**
 * This class represents a collection of errors, validation errors, and messages
 * that may be returned as a result of an action invocation. This class is used
 * to encapsulate that information as a struts independent Java object. That
 * object can be then serialized to XML and returned to the client. The error
 * collection contains general error messages, field validation errors, and
 * informational messages.
 * 
 * @author Leon Rubin
 */
public class ErrorCollection {
	private List<String> fieldErrors;
	private List<String> errors;
	private List<String> messages;

	/**
	 * Cretes an error collection.
	 */
	public ErrorCollection() {
		fieldErrors = new ArrayList<String>();
		errors = new ArrayList<String>();
		messages = new ArrayList<String>();
	}

	public boolean hasErrors() {
		return (fieldErrors.size() + errors.size()) > 0;
	}

	/**
	 * Gets the list of error messages.
	 * 
	 * @return List of strings where each element is an error that occured
	 *         during action execution.
	 */
	public List<String> getErrors() {
		return errors;
	}

	/**
	 * Adds an error message to the error list.
	 * 
	 * @param error
	 *            error message text
	 */
	public void addError(String error) {
		errors.add(error);
	}

	/**
	 * Gets the list of validation error messages.
	 * 
	 * @return List of strings where each element is a validation error that
	 *         occured during action input validation.
	 */
	public List<String> getFieldErrors() {
		return fieldErrors;
	}

	/**
	 * Adds a validation error message to the validation error list.
	 * 
	 * @param fieldError
	 *            validation error message text
	 */
	public void addFieldError(String fieldError) {
		fieldErrors.add(fieldError);
	}

	/**
	 * Gets the list of informational messages.
	 * 
	 * @return List of strings where each element is an informational message
	 *         that occured during action execution.
	 */
	public List<String> getMessages() {
		return messages;
	}

	/**
	 * Adds an informational message to the message list.
	 * 
	 * @param message
	 *            message text
	 */
	public void addMessages(String message) {
		messages.add(message);
	}
}
