package com.democompany.soa.esb.adaptor.util.http;

import java.util.Collections;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

/**
 * This abstract class contains the functionality necessary to manage a
 * collection of named attributes. Several classes in the Servlet API have named
 * attributes (HttpServletRequest, HttpSession, ServletContext, etc). This
 * abstract class allows reusing the attribute collection functionality.
 * 
 * @author Leon Rubin
 */
public abstract class AttributeCollection extends InitializableObject {
	private Map<String, Object> attributeMap;

	/**
	 * Creates an attribute collection.
	 */
	public AttributeCollection() {
		attributeMap = new HashMap<String, Object>();
	}

	/**
	 * Gets the attribute with a specified name.
	 * 
	 * @param name
	 *            attribute name
	 * @return Object associated with that attribute name (attribute value)
	 */
	public Object getAttribute(String name) {
		return attributeMap.get(name);
	}

	/**
	 * Removes the attribute with a specified name.
	 * 
	 * @param name
	 *            attribute name
	 */
	public void removeAttribute(String name) {
		attributeMap.remove(name);
	}

	/**
	 * Sets the attribute with a specified name to a specified value.
	 * 
	 * @param name
	 *            attribute name
	 * @param value
	 *            attribute value
	 */
	public void setAttribute(String name, Object value) {
		attributeMap.put(name, value);
	}

	/**
	 * Gets the names of all available attributes.
	 * 
	 * @return an Enumeration of attribute names
	 */
	public Enumeration getAttributeNames() {
		return Collections.enumeration(attributeMap.keySet());
	}
}
