package com.democompany.soa.esb.adaptor.util.http;

import java.util.Collections;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

/**
 * This abstract class contains the functionality common to all initializable
 * objects (Several classes in the Servlet API are initialized with a collection
 * of initial parameters (HttpServlet, ServletContext, FilterConfig, etc). This
 * class allows to reuse that functionality. Javadoc comments are not provided
 * because all methods will inherit them from the interfaces that the subclasses
 * of this class will implement.
 * 
 * @author Leon Rubin
 */
public abstract class InitializableObject {
	private Map<String, String> initParameterMap;

	/**
	 * Creates an initializable object.
	 */
	public InitializableObject() {
		initParameterMap = new HashMap<String, String>();
	}

	public Map<String, String> getInitParameterMap() {
		return initParameterMap;
	}

	public void setInitParameterMap(Map<String, String> initParameterMap) {
		this.initParameterMap = initParameterMap;
	}

	public String getInitParameter(String name) {
		return initParameterMap.get(name);
	}

	public Enumeration getInitParameterNames() {
		return Collections.enumeration(initParameterMap.keySet());
	}
}
