package com.onlinebank.transaction.to;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * This class is a transfer object used to encapsulate the results of the
 * transaction search as a single object.
 * 
 * @author Leon Rubin
 */
public class TransactionSearchResult implements Serializable {
	private static final long serialVersionUID = 1L;

	private List<Transaction> transactions;

	/**
	 * Creates a transaction search result object.
	 */
	public TransactionSearchResult() {
		transactions = new ArrayList<Transaction>();
	}

	/**
	 * Adds a transaction to the result list.
	 * 
	 * @param transaction
	 *            transaction to add to the result list
	 */
	public void addTransaction(Transaction transaction) {
		transactions.add(transaction);
	}

	/**
	 * Gets transactions that satisfy the search criteria as a list.
	 * 
	 * @return List of transactions that satisfy the search criteria.
	 */
	public List<Transaction> getTransactions() {
		return transactions;
	}
}
