package com.onlinebank.util.exception;

/**
 * This class represents a XML parsing or generation issue. XML parsers and
 * generators will typically receive vendor or framework specific exceptions
 * juch as Castor MappingException during marshalling or unmarshalling, but
 * since the purpose of the genrator is to abstract and hide the technology used
 * for XML processing, all such exceptions should be caught and wrapped as a
 * XMLExceptions.
 * 
 * @author Leon Rubin
 * 
 */
public class XMLException extends Exception {
	private static final long serialVersionUID = 1L;

	/**
	 * Creates an XML exception with a specified message.
	 * 
	 * @param message
	 *            exception messge
	 */
	public XMLException(String message) {
		super(message);
	}

	/**
	 * Creates a XML exception with a specified message that wraps another
	 * exception (the root cause of the problem).
	 * 
	 * @param message
	 *            exception messge
	 * @param rootCause
	 *            lower level exception that represents the root cause of the
	 *            problem
	 */
	public XMLException(String message, Throwable rootCause) {
		super(message, rootCause);
	}
}
